Full absolute path of the CSV file containing the dataset (e.g., '/home/data/my_data.csv'). Required when dataframe is None. Use get_data_home() or get_package_data_home() to build the path, for example fetch_data(filename=get_data_home() / "my_data.csv").
Timezone to set for the datetime index. If a DataFrame with naive index is provided, it will be localized to this timezone then converted to UTC. Default: “UTC”.
If columns is an empty list, if both filename and dataframe are provided, if neither filename nor dataframe is provided, or if filename is not an absolute path.
from spotforecast2_safe.data.fetch_data import fetch_data, get_package_data_home# demo02.csv is included in the package datasetspath_demo = get_package_data_home() /"demo02.csv"df = fetch_data(filename=path_demo)df.head()