Return the location where datasets are to be stored. By default the data directory is set to a folder named ‘spotforecast2_data’ in the user home folder. Alternatively, it can be set by the ‘SPOTFORECAST2_DATA’ environment variable or programmatically by giving an explicit folder path. The ‘~’ symbol is expanded to the user home folder. If the folder does not already exist, it is automatically created.